@@ -28,7 +28,7 @@
 
 class RDBManager: public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	RDBManager();
